/* This file starts with county-level data downloaded from LTCFocus and then merges in several datasets to create in the end a CZ-level dataset containing:

1) CZ-year outcomes and control variables for nursing homes from LTCFocus data
2) Cz-year population estimates (from NBER intercensal dataset)
3) Cz-year predicted immigration built by Burchardi et al., downloaded from https://www.immigrationshock.com/immigration-shocks
4) CZ-year immigration flows and Card prediction from the Census and ACS 

The data contain only years 2000, 2005, and 2010. For most variables, we have both the levels and the changes for each year. For changes, the change is between year t and 5 years earlier.

Note: The reason to download the county-level data from LTCFocus as opposed to the NH-level data is that data supression was less of an issue with county-level download. 
*/




******************************************************************************************************************************
*1. Continue cleaning nursing home data from LTCFocus
******************************************************************************************************************************

cd "C:\Data" 

set more off 


/* This data set in 4_Prepare_LTCFocusData.do*/ 

use LTCcty2000_2019, clear  


*a) Create a variable with common name even though definitions changed in 2011

*Note that pctfall30, avgadl defined up to 2010 and pctfall30_2011p, avgadl_2011p defined from 2011 onward

foreach var in pctfall30 avgadl pctblack pcthisp pctcath agg_cmi {
	gen my`var'=`var'_cty
	replace my`var'=`var'_mds3_cty if year>=2011
	}
	
replace myagg_cmi=agg_cmi_cty if year==2019

g myagglocare=agg_low_care if year<=2010
replace myagglocare=agglocare_mds3 if year>=2011

g myaggblack=agg_black if year<=2010
replace myaggblack=aggblack_mds3 if year>=2011

g myagghispanic=agg_hispanic if year<=2010
replace myagghispanic=agghisp_mds3 if year>=2011

g myaggwhite=agg_white if year<=2010
replace myaggwhite=aggwhite_mds3 if year>=2011


foreach var in pain adl pu {
	gen my`var'=nhc`var'_cty if year<=2010
	replace my`var'=nhc`var'_mds3_cty if year>=2017 
	}
	
replace mypain=	NHCpain_mds3_cty if year>=2011 & year<=2016
replace myadl=NHCADL_mds3_cty if year>=2011 & year<=2016
replace mypu=NHCpu_mds3_cty if year>=2011 & year<=2016

******************************************************************************************************************************
*2. Continue cleaning nursing home data from LTCFocus
******************************************************************************************************************************

*a) Estimate the number of nursing home residents by multiplying occupancy rate by the total number of nursing home beds 

gen residents=occpct*totbeds/100


*b) Create counts of incidents (vs. share of NH residents that experience them) 

gen nfall=residents*mypctfall/100
gen nrestrain=residents*restrain/100
gen npain=residents*mypain/100
gen nadl=residents*myadl/100
gen npu=residents*mypu/100
gen nuti=residents*pctuti/100
gen ncath=residents*mypctcath/100



*c) Replace the 2005 (missing) values for the NHCompare variables (ADL, pain, pressure ulcers) with 2006 values since NHCompare only starts in 2006. 
sort cty_fips year 
foreach X of varlist mypain myadl mypu npain nadl npu {	
	by cty_fips: replace `X'=`X'[_n+1] if  year==2005
	}  




******************************************************************************************************************************
*3. Keep only years 2000, 2005, 2010 from LTCfocus data and build 5-year differences as well as base year levels of variables  
******************************************************************************************************************************

keep if year==2000 | year==2005 | year==2010 


*a) Build the 5-year changes for each nursing home 
sort cty_fips year

foreach var of varlist mypctfall myavgadl mypain myadl mypu pctuti mypctcath restrain /*
	*/ nfall nrestrain npain nadl npu nuti ncath /*hrn hlpn hcna */ rnhrppd lpnhrppd cnahrppd residents acuindex2  myagg_cmi myagglocare myaggblack myagghispanic  myaggwhite agg_u65 agg_female {
	bysort cty_fips: gen D`var'=`var'[_n]-`var'[_n-1]
	}
	
*b) Build the lags, or the initial year in the five year period (since year t refers to the end year of the five year period). These are for the controls.
 
foreach var of varlist la_hha000e_cty la_nursall_000e_cty la_herfbeds_cty acuindex2 pctfem mypctblack mypcthisp pctobese  profit hospbase paymcaid paymcare multifac totbeds residents {	
	bysort cty_fips: gen L`var'=`var'[_n-1]
	}
 

keep  mypain myadl mypu mypctfall pctuti mypctcath restrain rnhrppd lpnhrppd cnahrppd nfall nrestrain nadl npain nadl npu nuti ncath /*
	*/ acuindex2 pctfem mypctblack mypcthisp pctobese  profit hospbase paymcaid paymcare multifac residents totbeds  D* L*  /*misdum* */  /*
	*/ year czone state statefip cty_fips myagg_cmi myagglocare la_herfbeds_cty

save ltc5yCTY_long.dta,replace    //nursing home level data with differences 

******************************************************************************************************************************
*4. Load and Prepare Data from NBER county population files, downloaded form NBER website.   
******************************************************************************************************************************

*Note: Use only years t=2000, 2005, 2010 and compute the changes in population. If t=2010, then this refers to the change between 2005 and 2010

cd "C:\Dropbox\Elderly\JHR replication files\Data\NBERpopulation" 

use nber_county_population.dta,clear

cd "C:\Data" 

keep fips state_fips county_fips areaname state_name county_name pop1995 pop2000 pop2005 pop2010 pop2013 pop2014
drop if county_fips==0

sort fips county_fips
by fips: gen Ncount=_N
tab Ncount
drop if Ncount==1
drop Ncount

sort fips county_fips
by fips: gen ncount=_n

*first collapse to COUNTIES
collapse (mean) pop1995 pop2000 pop2005 pop2010 pop2013 pop2014,by(fips county_name)

*we don't have 2015. We will make a projection assuming the same annual growth rate as 2013-2014
gen g1314=(pop2014/pop2013) -1
replace g1314=. if pop2013==.
replace g1314=. if pop2013==0

gen pop2015=pop2014*(1+g1314)
sum pop*

*we drop pop2013 pop2014 that we don't need anymore
drop pop2013 pop2014 g1314

*remove the leading zero in the fips
gen lead0=0
replace lead0=1 if strpos(fips,"0")==1

gen newfips=fips
replace newfips=usubstr(fips,2,4) if lead0==1
*br fips lead0 newfips
drop lead0 fips
ren newfips fips
destring fips,replace

ren fips cty_fips

*we bring in the crosswalk counties-czone
merge 1:1 cty_fips using "C:\Dropbox\Elderly\JHR replication files\Data\CommutingZones\cw_cty_czone.dta"

*only 9 unmatched counties from the master file
keep if _merge==3
drop _merge
drop cty_*

gen Dpop2000=pop2000 - pop1995
gen Dpop2005=pop2005 - pop2000
gen Dpop2010=pop2010 - pop2005
gen Dpop2015=pop2015 - pop2010
*sum pop*

gen poplag2005=pop2000
gen poplag2010=pop2005
gen poplag2015=pop2010

*now collapse to CZONE. Note we are SUMMING ALL COUNTIES IN A CZ.
collapse (sum) pop1995 pop2000 pop2005 pop2010 pop2015 Dpop2000 Dpop2005 Dpop2010 Dpop2015 poplag2005 poplag2010 poplag2015, by(czone)

save nberpop5ycz.dta,replace

reshape long pop Dpop poplag, i(czone) j(year)

save nberpop5ycz_long.dta,replace

******************************************************************************************************************************
*5. Load and Prepare Data on the BCHTT IV downloaded from immigrationshock.com   
******************************************************************************************************************************

/*Notes: This is a cunty level dataset with data for years t=2000, 2005, and 2010. Again, the change for year t=2010, refers to the difference between 
year 2005 and 2010.*/  

use "C:\Dropbox\Elderly\JHR replication files\Data\BurchardiIV\ImmigrationShock.dta", clear

cd "C:\Data" 


drop if Year<2000


*a) Create the FIPS county code so that we can merge this with other datasets/crosswalks. Need to remove the trailing 0 and add a leading 0

tostring CountyCode,gen(ff)

gen ll=length(ff)

gen fips="."
replace fips=substr(ff,1,5) if ll==6
replace fips=substr(ff,1,4) if ll==5

replace fips="0"+substr(ff,1,4) if ll==5

drop ff ll CountyCode Division PatentSample
ren Year year

ren Immigration Imm
ren ImmigrationNonEuropean ImmNoEu
ren ImmigrationShock ImmShock
ren PopulationChange PopCh


*b) Make wide dataset
reshape wide Imm* Pop*,i(fips State) j(year)

*c) remove the leading zero in the fips
gen lead0=0
replace lead0=1 if strpos(fips,"0")==1

gen newfips=fips
replace newfips=usubstr(fips,2,4) if lead0==1
drop lead0 fips
ren newfips fips
destring fips,replace

ren fips cty_fips

*d) Use the crosswalk from David Dorn's website to put counties into czones

merge 1:1 cty_fips using "C:\Dropbox\Elderly\JHR replication files\Data\CommutingZones\cw_cty_czone.dta"


*Perfect match
keep if _merge==3
drop _merge
drop cty_*

*e) Collapse by czone
collapse (sum) Imm2000 Imm2005 Imm2010 ImmShock2000 ImmShock2005 ImmShock2010 PopCh2000 PopCh2005 PopCh2010 , by(czone)

save immshock5ycz.dta,replace

reshape long Imm ImmShock PopCh, i(czone) j(year)

save immshock5ycz_long.dta,replace

******************************************************************************************************************************
*6. Prepare the Card IV  
******************************************************************************************************************************

use CardIV_levs_CZ.dta,clear  


ren inst1_70_levs_CZ predFB
ren num_imms FB

replace FB=FB/1000
replace predFB=predFB/1000


keep year czone FB predFB page65p pblack pimm pop_ipums nursewage RNwage LPNwage NAwage N_*   cz_N_* cz_Nfb_* cz_tot* cz_p25* cz_p50* cz_p75* wage_p50 pfemale phispan punemp pcol /* 
	*/ nurse RN LPN NA NH_RN NH_LPN NH_NA NH_RNwage NH_LPNwage NH_NAwage cz_uhrs_nurse  cz_uhrs_RN cz_uhrs_LPN  cz_uhrs_NA  


ren nursewage acsw_nurse
ren RNwage acsw_rn 
ren LPNwage acsw_lpn
ren NAwage acsw_cna

ren cz_N_RN acsn_rn
ren cz_N_LPN acsn_lpn
ren cz_N_NA acsn_cna
ren cz_N_nurse acsn_nurse 


ren cz_Nfb_RN acsn_FBrn
ren cz_Nfb_LPN acsn_FBlpn
ren cz_Nfb_NA acsn_FBcna

ren cz_totNH_RN acsnh_n_rn
ren cz_totNH_LPN acsnh_n_lpn
ren cz_totNH_NA acsnh_n_cna
ren cz_totNH_notnurse acsnh_n_nonurse

ren cz_tothrs_RN acs_tothrs_rn
ren cz_tothrs_LPN acs_tothrs_lpn
ren cz_tothrs_NA acs_tothrs_cna

ren cz_tothrs_imm acs_tothrs_imm


ren cz_p25_RN acsp25w_rn
ren cz_p25_LPN acsp25w_lpn
ren cz_p25_NA acsp25w_cna

ren cz_p50_RN acsp50w_rn
ren cz_p50_LPN acsp50w_lpn
ren cz_p50_NA acsp50w_cna

ren cz_p75_RN acsp75w_rn
ren cz_p75_LPN acsp75w_lpn
ren cz_p75_NA acsp75w_cna


ren pop_ipums acs_pop
ren pimm acs_pimm
ren page65p acs_page65p
ren pblack acs_pblack

sort czone year
order czone year
by czone: gen DFB=FB[_n]-FB[_n-1]
by czone: gen DpredFB=predFB[_n]-predFB[_n-1]


by czone: gen Dacs_pimm=acs_pimm[_n] - acs_pimm[_n-1]
by czone: gen Dacs_pop=acs_pop[_n] - acs_pop[_n-1]


by czone: gen acs_Lpage65p=acs_page65p[_n-1]
by czone: gen acs_Lpblack=acs_pblack[_n-1]
by czone: gen acs_Lwage_p50=wage_p50[_n-1]

by czone: gen acs_Lpop=acs_pop[_n-1]


foreach var of varlist pfemale phispan punemp pcol {
	bysort czone: gen acs_L`var'=`var'[_n-1]
	}

by czone: gen Dacs_w_nurse=acsw_nurse[_n] - acsw_nurse[_n-1]
by czone: gen Dacs_w_rn=acsw_rn[_n] - acsw_rn[_n-1]
by czone: gen Dacs_w_lpn=acsw_lpn[_n] - acsw_lpn[_n-1]
by czone: gen Dacs_w_cna=acsw_cna[_n] - acsw_cna[_n-1]

by czone: gen Dacsnh_n_rn=acsnh_n_rn[_n] - acsnh_n_rn[_n-1]
by czone: gen Dacsnh_n_lpn=acsnh_n_lpn[_n] - acsnh_n_lpn[_n-1]
by czone: gen Dacsnh_n_cna=acsnh_n_cna[_n] - acsnh_n_cna[_n-1]

by czone: gen Dacs_p25w_rn=acsp25w_rn[_n] - acsp25w_rn[_n-1]
by czone: gen Dacs_p25w_lpn=acsp25w_lpn[_n] - acsp25w_lpn[_n-1]
by czone: gen Dacs_p25w_cna=acsp25w_cna[_n] - acsp25w_cna[_n-1]

by czone: gen Dacs_p50w_rn=acsp50w_rn[_n] - acsp50w_rn[_n-1]
by czone: gen Dacs_p50w_lpn=acsp50w_lpn[_n] - acsp50w_lpn[_n-1]
by czone: gen Dacs_p50w_cna=acsp50w_cna[_n] - acsp50w_cna[_n-1]

by czone: gen Dacs_p75w_rn=acsp75w_rn[_n] - acsp75w_rn[_n-1]
by czone: gen Dacs_p75w_lpn=acsp75w_lpn[_n] - acsp75w_lpn[_n-1]
by czone: gen Dacs_p75w_cna=acsp75w_cna[_n] - acsp75w_cna[_n-1]

by czone: gen Dacs_n_rn=acsn_rn[_n] - acsn_rn[_n-1]
by czone: gen Dacs_n_lpn=acsn_lpn[_n] - acsn_lpn[_n-1]
by czone: gen Dacs_n_cna=acsn_cna[_n] - acsn_cna[_n-1]

by czone: gen Dacs_n_nurse=acsn_nurse[_n] - acsn_nurse[_n-1]

/***the new variables for the revision***/

by czone: gen Dacs_n_funeral=cz_N_funeral[_n] - cz_N_funeral[_n-1]
by czone: gen Dacs_n_LawEnforc=cz_N_LawEnforc[_n] - cz_N_LawEnforc[_n-1]



foreach num of numlist 1   {
	by czone: gen Dacs_n_p`num'= N_perFBocc`num'[_n]  - N_perFBocc`num'[_n-1]
	}

****


by czone: gen Dacs_tothrs_rn=acs_tothrs_rn[_n] - acs_tothrs_rn[_n-1]
by czone: gen Dacs_tothrs_lpn=acs_tothrs_lpn[_n] - acs_tothrs_lpn[_n-1]
by czone: gen Dacs_tothrs_cna=acs_tothrs_cna[_n] - acs_tothrs_cna[_n-1]


foreach X in rn lpn cna {
	bysort czone: gen Dacs_nFB_`X'=acsn_FB`X'[_n]-acsn_FB`X'[_n-1]
	gen Dacs_nFB_`X'_D1000=Dacs_nFB_`X'/1000
	}
	
g Dacs_nFB_nurse=Dacs_nFB_rn + Dacs_nFB_lpn+Dacs_nFB_cna
gen Dacs_nFB_nurse_D1000=Dacs_nFB_nurse/1000



foreach var of varlist Dacs_tothrs_rn Dacs_tothrs_lpn Dacs_tothrs_cna acs_tothrs_rn acs_tothrs_lpn acs_tothrs_cna {
	gen `var'_D1000=`var'/1000
	}
	
keep DFB FB DpredFB acsp50w_rn acsp50w_lpn acsp50w_cna acs_Lpage65p acs_Lpblack acs_Lwage_p50 acs_Lpop Dacs* czone year acs_L* acs_tothrs_rn* acs_tothrs_lpn* acs_tothrs_cna* acsnh* acsn* /*
	*/ nurse RN LPN NA NH_RN NH_LPN NH_NA NH_RNwage NH_LPNwage NH_NAwage cz_uhrs_nurse  cz_uhrs_RN cz_uhrs_LPN  cz_uhrs_NA 


*drop if year==2000

*reshape wide DFB DpredFB acs_Lpage65p acs_Lpblack acs_Lpop Dacs*,i(czone) j(year)



save card_dlevs_long.dta,replace


******************************************************************************************************************************
*7. Merge all of the different data sets together by czone and year 
******************************************************************************************************************************

*a) Merge the NBER population data with the Burchardi IV data and the Card IV 

use nberpop5ycz_long, clear 

merge czone year using immshock5ycz_long card_dlevs_long 
keep if _merge==3  //this just drops 1995 from the NBER website 
drop _merge*

*b) Merge in the  nursing home data 

merge 1:m czone year using  ltc5yCTY_long.dta

tab czone year if _m==1  //there are  115 czone-years with no counties w/nursing homes in them 

drop if _m==1

drop _merge 

******************************************************************************************************************************
*8. Final Adjustments to Variables before Running Regressions 
******************************************************************************************************************************

*a)  Rescale NBER pop changes to thousands
replace Dpop=Dpop/1000
replace pop=pop/1000
ren Dpop DPop
replace poplag=poplag/1000
ren acs_Lpop acs_poplag
replace acs_poplag=acs_poplag/1000


*b) Generate immigration flow per capita. NOTICE THAT THE DENOMINATOR IS THE LAGGED VALUE OF POPULATION, NOT SAME YEAR POPULATION 
sort czone year
gen pImm=100*Imm/poplag
gen pDPop=100*DPop/poplag
*gen acs_pIm=100*acs_Im/poplag
gen acs_pDFB=100*DFB/poplag

gen pImmShock=100*ImmShock/poplag
*gen pacsImmShock=100*acs_predIm/poplag

gen predpDFB=100*DpredFB/poplag

gen lpoplag=ln(poplag)



*c) Rename immigration variables 

**Buchardi's immigration variable
ren Imm ImBuch
ren pImm pImBuch


**Buchardi's prediction
ren ImmShock predImBuch
*ren pImmShock predpImBuch

**Card prediction of ACS immigration (arrivals last 5 years) PREFERRED
*ren acs_predIm predImCard
*ren pacsImmShock predpImCard


**Card prediction of ACS CHANGE IN FB
ren DpredFB predDFB


egen fe_state_y = group(statefip year)  //In Francesc's original file, he used "modeState" which is really modemodeState (from Buchardi's file)---it's the mean modeState for counties in the CZ. Great for 90% but nto all. 

save fullCZ5ylongCNTY.dta, replace  

******************************************************************************************************************************
** 9. Construct the CZ-year variables 
******************************************************************************************************************************

*a) These are the totals in each CZ-year. Notice: no weights necessary for these. 

collapse  (sum)  cz_N_totbeds=totbeds Lcz_N_totbeds=Ltotbeds cz_N_residents=residents Lcz_N_residents=Lresidents cz_N_Dresidents=Dresidents cz_N_Dnfall=Dnfall cz_N_Dnrestrain=Dnrestrain cz_N_Dnadl=Dnadl  cz_N_Dnpain=Dnpain  cz_N_Dnpu=Dnpu cz_N_Dnuti=Dnuti cz_N_Dncath=Dncath /*
	*/ nfall nrestrain npain nadl npu nuti ncath, by(czone year) // LTCFocus outcome variables 

/* This collapse statement assigns zeros to counties with missing data. This is usually fine because it's mostly driven by small numbers of cases, but it also 
assigns zeros to cases where the data just wasn't collected, as is the case for the NHCompare variables in the year 2000. In the code below, I replace the zeros in 2005
with missing data*/ 
  
foreach var of varlist cz_N_Dnadl cz_N_Dnpain cz_N_Dnpu {
	replace `var'=. if year==2005  | year==2000
	}
	
save temp_Ncz, replace 


*b) These are the means over all nursing homes in each CZ-year. Notice: We weight by the number of residents in each nursing home (in that CZ-year).  

use fullCZ5ylongCNTY.dta,clear 

collapse (mean) cz_N_Dacsnh_n_rn=Dacsnh_n_rn cz_N_Dacsnh_n_lpn=Dacsnh_n_lpn cz_N_Dacsnh_n_cna=Dacsnh_n_cna /* DIFFERENCE IN Number of nurses working in nursing homes, ACS 
	*/ cz_N_Dacs_n_nurse=Dacs_n_nurse cz_N_Dacs_n_rn=Dacs_n_rn cz_N_Dacs_n_lpn=Dacs_n_lpn cz_N_Dacs_n_cna=Dacs_n_cna     /* DIFFERENCE IN Number of nurses, from ACS 
	*/  cz_N_Dacs_n_funeral=Dacs_n_funeral cz_N_Dacs_n_LawEnforc=Dacs_n_LawEnforc  /* DIFFERENCE in number of lawyers, dentists, funeral directors, and law enforcemtn 
	*/ Dacs_n_p1 /* these are the new varisables for revision, difference in nmber in occupations with few immigrants 	
	*/ Dacs_nFB_nurse Dacs_nFB_rn Dacs_nFB_lpn Dacs_nFB_cna	 /*DIFFERENCE in number of foreign born nurses
	*/ cz_N_Dacs_tothrs_rn=Dacs_tothrs_rn cz_N_Dacs_tothrs_lpn=Dacs_tothrs_lpn cz_N_Dacs_tothrs_cna=Dacs_tothrs_cna /* DIFFERENCE IN Total hours worked by nurses, from ACS	
	*/ cz_N_Dacs_tothrs_rn1000=Dacs_tothrs_rn_D1000 cz_N_Dacs_tothrs_lpn1000=Dacs_tothrs_lpn_D1000 cz_N_Dacs_tothrs_cna1000=Dacs_tothrs_cna_D1000 /* DIFFERENCE IN Total hours worked by nurses, from ACS DIVIDED BY 1000
	*/ acsp50w_rn acsp50w_lpn acsp50w_cna /*
	*/ Dmyagg_cmi Dmyagglocare Dmyaggblack Dmyagghispanic  Dmyaggwhite Dagg_u65 Dagg_female Dacuindex /*  5-year differences in characteristics of new entrants and average acuity of residents
	*/ DFB  FB predImBuch  predDFB Dacs_pop  acs_Lpage65p acs_Lpblack acs_Lwage_p50 acs_Lphispan acs_Lpunemp acs_Lpfemale /* ACS measures of foreign born and other CZ-characteristics from ACS 
	*/ Dmypctfall Dmyavgadl Dmypain Dmyadl Dmypu Dpctuti Dmypctcath Drestrain_cty  /* DIFFERENCE IN Per nursing home resident NH outcomes
	*/ lpoplag poplag Ltotbeds Lresidents Lacuindex Lpctfem  Lmypctblack  Lmypcthisp Lpctobese Lprofit Lpaymcaid Lpaymcare Lmultifac Lhospbase /* controls from LTCFocus
	*/ acs_tothrs_rn* acs_tothrs_lpn* acs_tothrs_cna* acsnh* acsn_rn acsn_lpn acsn_cna statefip  myagg_cmi myagglocare /*
	*/ RN LPN NA NH_RN NH_LPN NH_NA NH_RNwage NH_LPNwage NH_NAwage cz_uhrs_nurse  cz_uhrs_RN cz_uhrs_LPN  cz_uhrs_NA   rnhrppd lpnhrppd cnahrppd fe_state_y [pw=residents], by(czone year) //Labor market outcomes 

	*Putting this variable here because didn't construct it with the others. 
	
	g cz_N_Dacsnh_n_nurse= cz_N_Dacsnh_n_rn+cz_N_Dacsnh_n_lpn + cz_N_Dacsnh_n_cna
	
	foreach var of varlist myagg_cmi myagglocare acsp50w_rn acsp50w_lpn acsp50w_cna NH_RNwage NH_LPNwage NH_NAwage {
	g log`var'=log(`var') 
	bysort czone: g Dlog`var'=log`var'[_n]- log`var'[_n-1]
	}

*c) Merge the totals and means together 	
	
merge 1:1 czone year using temp_Ncz

drop if _merge==2

drop _merge 

*d) More variable construction 

	
foreach var of varlist cz_N_Dnfall cz_N_Dnrestrain  cz_N_Dnpain  cz_N_Dnadl cz_N_Dnpu cz_N_Dnuti cz_N_Dncath {
	gen `var'pRes=`var'/Lresidents
	gen `var'pPop=`var'/poplag
	}
	

foreach var of varlist myagg_cmi myagglocare  {
	bysort czone: g Dnew_`var'= `var'[_n]- `var'[_n-1]
	}

	
	


	
save CZ5ylongCNTY.dta, replace



erase  temp_Ncz.dta 



